#
# spec file for package python-gevent
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-gevent
Version:        1.0.2
Release:        4.2
Url:            http://www.gevent.org/
Summary:        Python network library that uses greenlet and libevent
License:        MIT
Group:          Development/Languages/Python
Source:         http://pypi.python.org/packages/source/g/gevent/gevent-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  libevent-devel
#BuildRequires:  python-Sphinx
BuildRequires:  python-devel
BuildRequires:  python-greenlet
BuildRequires:  python-nose
Requires:       python-greenlet
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitearch: %global python_sitearch %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib(1)")}
%endif

%description
Gevent is a Python networking library that uses greenlet to provide synchronous
API on top of a libevent event loop. Features include:

  * Fast event loop based on libevent.
  * Lightweight execution units based on greenlet.
  * Familiar API that re-uses concepts from the Python standard library.
  * Cooperative sockets with ssl support.
  * DNS queries performed through libevent-dns.
  * Ability to use standard library and 3rd party modules written for standard
    blocking sockets
  * Fast WSGI server based on libevent-http.

gevent is inspired by eventlet but features more consistent API, simpler
implementation and better performance. Read why others use gevent and check
out the list of the open source projects based on gevent.

%prep
%setup -q -n gevent-%{version}

%build
CFLAGS="%{optflags} -fno-strict-aliasing" python setup.py build
#cd doc && make html && rm _build/html/.buildinfo # Build HTML documentation

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

%check
nosetests

%files
%defattr(-,root,root,-)
%doc AUTHORS changelog.rst LICENSE* README.rst TODO examples
#%%doc doc/_build/html
%{python_sitearch}/*

%changelog
* Tue Jun 30 2015 tchvatal@suse.com
- Version bump to 1.0.2:
  - Fix LifoQueue.peek() to return correct element. PR #456. Patch by Christine
    Spang.
  - Upgrade to libev 4.19
  - Remove SSL3 entirely as default TLS protocol
  - Import socket on Windows (closes #459)
  - Fix C90 syntax error (PR #449)
  - Add compatibility with Python 2.7.9's SSL changes. Issue #477.
* Tue Nov 18 2014 toddrme2178@gmail.com
- Update to 1.0.1
  - Upgrade libev to 4.15. This fixes #361: installation on armv5.
  - Better support for win64. Patch by Alexey Borzenkov.
  - Fix #423: Pool's imap/imap_unordered could hang forever. Based on patch and test by Jianfei Wang.
  - Enable libev's check watchers.
  - Add dummy Event._reset_internal_locks() method. Only relevant if patch_all(Event=True) is enabled (non-default).
  - Backport new testrunner.py from master branch.
- Removed upstream included libev.patch
* Thu Jun 12 2014 schwab@suse.de
- libev.patch: fix syntax error in preprocessor conditional
* Sun Dec 15 2013 p.drouand@gmail.com
- Update to version 1.0
  + pywsgi: Pass copy of error list instead of direct reference
  + Ignore the autogenerated doc/gevent.*.rst files.
  + Fix cythonpp.py on Windows.
  + Remove gevent.run (use gevent.wait).
* Fri Oct 26 2012 douglarek@outlook.com
- Update to version 0.13.8:
  * Fixed issue #80: gevent.httplib failed with RequestFailed errors because timeout was reset to 1s. Patch by Tomasz Prus.
  * core: fix compilation with the latest Cython: remove emit_ifdef/emit_else/emit_endif.
  * Fixed issue #132: gevent.socket.gethostbyname(<unicode>) now does ascii encoding and uses gevent's resolver rather than
    calling built-in resolver. Patch by Alexey Borzenkov.
* Mon Jun 25 2012 saschpe@suse.de
- Update to version 0.13.7:
  + Fixed #94: fallback to buffer if memoryview fails in _get_memory on
    python 2.7.
  + Fixed #103: ``Queue(None).full()`` returns ``False`` now (previously
    it returned ``True``).
  + Fixed #112: threading._sleep is not patched.
  + Fixed #115: _dummy gets unexpected Timeout arg.
* Tue Mar 27 2012 saschpe@suse.de
- Run testsuite
- Require python-greenlet
- Simplify macro usage
* Fri Nov 18 2011 saschpe@suse.de
- Cython should not be needed, gevent is build as a binary module
* Tue Jul 19 2011 saschpe@suse.de
- Initial version
